%%%%%% This code generates the evolutionary dynamics of A-L+ in excess
%%%%%% hypoxanthine
clear all;
close all;

global gA gE cr

gA =0.438 ; %Anc growth rate in excess hypoxanthine; per hr
gE=0.231; %Evo growth rate in excess hypoxanthine; per hr

% data from 2017-11-13_colony_evo
% Col 1: fraction evolved; Col 2: - confidence interval; Col 3: + confidence interval 
% two rows correspond to two time points
Exp_20171113=[0.0142 0.0142 0.0201
0.0282 0.0282 0.0282];

time=[0.00
14];

cr=0.01;%conversion from A to E
c0=[47142/1000000;47142/1000000*0.0142];% initial condition
tsstep=0.5; % time step for evaluating ODE
tspan=0:tsstep:14;% duration for evaluating ODE
[t h]=ode23s(@Expfunc,tspan, c0);

figure (1)
plot(t, h(:,2)./(h(:,1)+h(:,2)), '-','color', [153/255 102/255 0])
hold on
plot(time, Exp_20171113(:,1), 'o', 'color', [153/255 102/255 0])
tb=terrorbar(time, Exp_20171113(:,1),Exp_20171113(:,2), Exp_20171113(:,3), 0.25, 'centi')
set(tb, 'color', [153/255 102/255 0])
xlabel('Time (hr)')
ylabel('Fraction evolved')
xlim([-0.5 15])
ylim([-0.01 0.15])


cr=0.003; %try a different rate
c0=[47142/1000000;47142/1000000*0.0342]; %starting at the highest point of confidence interval
[t h]=ode23s(@Expfunc,tspan, c0);
plot(t, h(:,2)./(h(:,1)+h(:,2)), ':','color', [153/255 102/255 0])


% data from 2017-10-24_1340_colony_evolution
% Col 1: fraction evolved; Col 2: - confidence interval; Col 3: + confidence interval 
% two rows correspond to two time points
Exp_20171113=[0.0263	0.0235	0.0235
0.0798	0.0412 0.0412];

time=[0.00
12.55];

c0=[210000/1000000;210000/1000000*0.0263];% initial condition
cr=0.01;%conversion
tspan=0:tsstep:13;% duration for evaluating ODE

[t h]=ode23s(@Expfunc,tspan, c0);
plot(t, h(:,2)./(h(:,1)+h(:,2)), 'b-')
plot(time+0.2, Exp_20171113(:,1), 'bo')
tb=terrorbar(time+0.2, Exp_20171113(:,1),Exp_20171113(:,2), Exp_20171113(:,3), 0.25, 'centi')
set(tb, 'color', 'b')

cr=0.003; %try a different rate
c0=[210000/1000000;210000/1000000*0.050]; %starting at the highest point of confidence interval
[t h]=ode23s(@Expfunc,tspan, c0);
plot(t, h(:,2)./(h(:,1)+h(:,2)), 'b:')

hold off
set(gca, 'ticklength', [0.025, 0.05])
set(gcf,'units', 'inches', 'position', [1 1 6 4.5])
