
close all;
clear all;

global dil gA gE KA KE nA nE cr H0 cHA cHE dA dE
dil=0.0866; %dilution rate, per hr
H0=20; %reservior hyp conc, uM

gA =0.44 ; %maximal growth rate of Anc, per hr
nA=1.27; % growth cooperativity for Anc
KA = 1.18; %Hyp conc at which half maximal growth rate is achieved for Anc, uM
dA=0.0092 ; %death rate of Anc (measured from the same run of chemostats), per hr
cHA = 2.6; %Hyp consumed by Anc (measured from the same run of chemostats), fmole/cell
gE=0.231; %maximal growth rate of Evo, per hr
nE=1.3; %growth cooperativity for Evo
KE=0.43; %Hyp conc at which half maximal growth rate is achieved for Evo, uM
dE=0.0008; %death rate of Evo (measured from the same run of chemostats), per hr
cHE = 1.6; %Hyp consumed by Evo (measured from the same run of chemostats), fmole/cell
cr=0.01; %conversion rate (per cell per generation)


tsstep=0.5; % time step for evaluating ODE
tspan=0:tsstep:90;% duration for evaluating ODE

c0=[1.5E6/1000000;0; 1.5E3/1000000; 0];
%low ratio initial conditions (pop density (million/ml) of input Anc , Evo converted from Anc, input Evo, Hyp (uM))

%experimental time point
time=[0.00
6.25
11.25
21.25
26.0
29.5
49.3];

%Col 1: Anc (GFP); Col 2: Input Evo (Citrine)
data20170111_3=[1.4E+06	1.5E+03
5.8E+06	3.4E+03
7.4E+06	4.6E+03
7.3E+06	6.0E+03
7.8E+06	5.3E+03
7.3E+06	7.1E+03
6.4E+06	7.7E+03];

data20170111_4=[1.4E+06	1.5E+03
5.5E+06	2.4E+03
7.9E+06	3.8E+03
7.2E+06	5.4E+03
7.4E+06	5.7E+03
6.8E+06	5.3E+03
5.9E+06	7.6E+03];

[t h]=ode23s(@ChemoCompfunc,tspan, c0);
figure (1)
semilogy(t, h(:,3)./(h(:,1)+h(:,2)), 'r-')
hold on
semilogy(time, data20170111_3(:,2)./data20170111_3(:,1), 'ko')
semilogy(time, data20170111_4(:,2)./data20170111_4(:,1), 'ks')
xlim([0 50])

newStr=strcat('KA=', num2str(KA), ' nA=', num2str(nA), ' KE=', num2str(KE), ' nE=', num2str(nE), ' cr=', num2str(cr))
title(newStr) 

c0=[6.7E+05/1000000;0;8.4E+05/1000000; 0];
% high ratio initial conditions (pop density (million/ml) of input Anc , Evo converted from Anc, input Evo, Hyp (uM))
[t h]=ode23s(@ChemoCompfunc,tspan, c0);

%Col 1: Anc (GFP); Col 2: Input Evo (Citrine)
data20170111_6=[6.7E+05	8.4E+05
3.0E+06	1.7E+06
5.0E+06	2.9E+06
5.6E+06	4.1E+06
5.8E+06	4.6E+06
5.2E+06	4.6E+06
4.0E+06	4.8E+06];

data20170111_5=[6.7E+05	8.4E+05
3.0E+06	1.7E+06
5.1E+06	2.8E+06
5.6E+06	4.0E+06
5.8E+06	4.6E+06
5.0E+06	4.5E+06
4.0E+06	5.0E+06];


semilogy(t, h(:,3)./(h(:,1)+h(:,2)), 'r-')
semilogy(time, data20170111_5(:,2)./data20170111_5(:,1), 'ko')
semilogy(time, data20170111_6(:,2)./data20170111_6(:,1), 'ks')
hold off
xlabel('Time (hr)')
ylabel('2447/1335')
ylim([0.0003 3])
xlim([0 50])
title(newStr)
set(gcf,'units','inches','position',[2,2,6,4.5])
set(gca, 'ticklength',[0.015 0.05])

%Col 1:  hyp; Col 2: growth rate; Col 3: confidence interval
Kanc=[0	0.02	0.00
0.1	0.03	0.00
0.2	0.04	0.01
0.4	0.08	0.02
0.6	0.11	0.01
1	0.16	0.03
2	0.28	0.04
5	0.37	0.02
20	0.42	0.01];

K2447=[0	0.01	0.00
0.1	0.02	0.01
0.2	0.04	0.01
0.4	0.10	0.02
0.6	0.16	0.01
1	0.20	0.01
2	0.22	0.01
5	0.23	0.01
20	0.23	0.01];

h=[0:0.1:20]; %range of hyp concs for calculating growth rate 

figure(2)
plot(Kanc(:,1),Kanc(:,2),'mo')
hold on
plot(h, gA*h.^nA./(h.^nA+KA^nA),'m--')
plot(K2447(:,1),K2447(:,2),'go')
plot(h, gE*h.^nE./(h.^nE+KE^nE),'g--')
hA=terrorbar(Kanc(:,1),Kanc(:,2),Kanc(:,3),Kanc(:,3), 0.25, 'centi')
hE=terrorbar(K2447(:,1),K2447(:,2),K2447(:,3),K2447(:,3), 0.25, 'centi')
set(hA, 'color', 'm')
set(hE, 'color', 'g')
hold off
title('m: 1340; g: 2447')
xlim([-0.2 20.2])
ylim([0 0.45])
xlabel('hyp')
ylabel('growth rate')
set(gcf,'units','inches','position',[2,2,6,4.5])
set(gca, 'ticklength',[0.015 0.05])

figure(3)
plot(Kanc(:,1),Kanc(:,2),'mo')
hold on
plot(h, gA*h.^nA./(h.^nA+KA^nA),'m--')
plot(K2447(:,1),K2447(:,2),'go')
plot(h, gE*h.^nE./(h.^nE+KE^nE),'g--')
hA=terrorbar(Kanc(:,1),Kanc(:,2),Kanc(:,3),Kanc(:,3), 0.02, 'centi')
hE=terrorbar(K2447(:,1),K2447(:,2),K2447(:,3),K2447(:,3), 0.02, 'centi')
set(hA, 'color', 'm')
set(hE, 'color', 'g')
hold off
title('m: 1340; g: 2447')
xlim([-0.1 2.1])
xlabel('hyp')
ylabel('growth rate')
set(gca, 'ticklength',[0.025 0.05])




